#!/bin/bash

# directory where temporary ramdisk & cramfs directories have to be created
# and where the INITRD_IMG file from targetconf can be found.
INITRD_SRCDIR=`pwd`

# temporary ramdisk directory name
INITRD_MNT_DIR=rdiskdir

# temporary cramfs directory name
CRAMFS_DIR=cramfs

# directory where image need to be created
GZIP_IMG_DIR=$LINUX_SRC

#final initrd image name
INITRD_IMG=initrd.o

#disk image name
DISK_IMG=disk.img

#cramfs image name
CRAMFS_IMG=cramfs.img

#name of tar file created by targetconf
TAR_INITRD_IMG=fsimage.tgz 

#image name for gzipped ramdisk image
GZIP_INITRD_IMG=ramdisk.gz 

#linker command definition
LD=xscale_be-ld

#linux directory
LINUX_DIR=`pwd`

###################################################
INST_RDISK_DIR=$INITRD_SRCDIR/$INITRD_MNT_DIR
INST_CRAMFS_DIR=$INITRD_SRCDIR/$CRAMFS_DIR
export INST_RDISK_DIR INST_CRAMFS_DIR 

CWD=`pwd`

# create temporary ramdisk & cramfs directories
echo "creating temp ramdisk dir"
cd $INITRD_SRCDIR
if [ -d $INITRD_MNT_DIR ]
then
rm -rf $INITRD_MNT_DIR
fi
mkdir $INITRD_MNT_DIR
chmod 777 $INITRD_MNT_DIR

#create cramfs directory if it does not exist, clear contents anyway
echo "creating temp cramfs dir"
if [ -d $CRAMFS_DIR ]
then
rm -rf $CRAMFS_DIR
fi
mkdir $CRAMFS_DIR
chmod 777 $CRAMFS_DIR

#copy ethernet drivers & other insertable modules to cramfs
cp $LINUX_DIR/drivers/csr/csr.o $CRAMFS_DIR/
cp $LINUX_DIR/drivers/net/ixp425_eth.o $CRAMFS_DIR/
cp $LINUX_DIR/drivers/net/eepro100.o $CRAMFS_DIR/

#Chuck
cp $HARDHAT_BASE/devkit/arm/xscale_be/target/usr/sbin/eraseall $CRAMFS_DIR/
$HARDHAT_BASE/devkit/arm/xscale_be/bin/xscale_be-strip $CRAMFS_DIR/eraseall

# create a initrd image
dd if=/dev/zero of=$DISK_IMG bs=1024 count=5000

#make an ext2 file system on it
/sbin/mke2fs -F $DISK_IMG

# mount this image
mount -oloop $DISK_IMG $INITRD_SRCDIR/$INITRD_MNT_DIR

#untar the image created using targetconf utility
echo "creating rdiskimg"
cd $INITRD_SRCDIR/$INITRD_MNT_DIR
tar -zxf $INITRD_SRCDIR/$TAR_INITRD_IMG

# Forrest: repair the system time
echo "date `date +%m%d%H%M%Y`>/dev/null">etc/rc.d/rcS.d/S10date.sh
chmod +x etc/rc.d/rcS.d/S10date.sh

#create cramfs directory
cd mnt
mkdir cramfs

#copy files from $(OEM) to ramdisk & cramfs
cd $GZIP_IMG_DIR
./CpIgw

#unmount ramdisk image
umount $INITRD_SRCDIR/$INITRD_MNT_DIR

cd $GZIP_IMG_DIR

#remove old ramdisk image
if [ -f $GZIP_INITRD_IMG ]
then
rm $GZIP_INITRD_IMG
fi

#zip the ramdisk image
gzip -9 -c $DISK_IMG > $INITRD_IMG
rm $DISK_IMG

#convert to .o
$LD -s -r -o img.o -b binary $INITRD_IMG

mv img.o $INITRD_IMG 

