// wag302mib.h
//

#ifndef __WAG302MIB_H__
#define __WAG302MIB_H__

#include "wag302def.h"

///////////////////////////////////////////////////////////////////////////////
//	Config server and client revision
///////////////////////////////////////////////////////////////////////////////
// if the MIB IDs' definition updated, CONFIG_REVISION will be increased
#define	CONFIG_REVISION		"2.1.1"

///////////////////////////////////////////////////////////////////////////////
//	Config server MIB IDs
///////////////////////////////////////////////////////////////////////////////
#define MIB_WG302_BASE		0x60b30000	//Z-Com Vendor ID of Mac Address

typedef enum MIBSystem_t
{
	MIB_SYSTEM_FIRST		= MIB_WG302_BASE + 0x0000,

	MIB_PRODUCT				= MIB_SYSTEM_FIRST,	// read-only
	MIB_PRODUCT_NAME,
	MIB_HOST_NAME_PERMANENT,
	MIB_HOST_NAME,
	MIB_FIRMWARE_VERSION,

	MIB_USER_NAME,
	MIB_PASSWORD,				// remove means set to default

	MIB_TIME_SERVER,
	MIB_TIME_SERVER_PORT,
	MIB_TIME_ZONE,				// dst info built-in, see IS_DST_SUPPORT
	MIB_TIME_ZONE_INDEX,		// access time zone by index,
	MIB_TIME_DAYLIGHT_SAVING,
	MIB_TIME,

	MIB_REBOOT,					// write-only
	MIB_RESTORE_FACTORY,		// write-only

	//Config File/Firmware and so on
	MIB_FILE_ACCESS_START,
	MIB_FILE_ACCESS_FINISH,

#if defined(ZAG5000)
	MIB_WLAN_BEEP,
#endif

	MIB_SYSTEM_RESET_TIME,

	MIB_SYSTEM_LAST
} MIBSystem_t;

typedef enum MIBNetwork_t
{
	MIB_NETWORK_FIRST		= MIB_WG302_BASE + 0x0100,

	MIB_SYS_MAC_ADDRESS		= MIB_NETWORK_FIRST,
	MIB_SYS_COUNTRY,
	MIB_SYS_COUNTRY_IS_DEFAULT,	// read-only

	MIB_BRIDGE_SPANNING_TREE,
#if	defined(ZAG5000) || defined(AG3120) && !defined(BWA8110A)
	MIB_ROUTE_MODE,
	MIB_ANYIP_ON_ROUTE,

	MIB_NET_TYPE,
	MIB_NET_IP,
	MIB_NET_MASK,
	MIB_NET_GATEWAY,
	MIB_NET_DNS_PRIMARY,
	MIB_NET_DNS_SECONDARY,

	MIB_IP_RANGE_START,
	MIB_IP_RANGE_END,
	MIB_IP_RANGE_NETMASK,
#else
	MIB_DHCP_CLIENT_DAEMON,
	MIB_BRIDGE_IPADDRESS,
	MIB_BRIDGE_NETMASK,
	MIB_BRIDGE_GATEWAY,
	MIB_BRIDGE_DNS_PRIMARY,
	MIB_BRIDGE_DNS_SECONDARY,

	MIB_DHCPS_DAEMON,
	MIB_DHCPS_ANYIP,
	MIB_DHCPS_IP_RANGE_START,
	MIB_DHCPS_IP_RANGE_END,
	MIB_DHCPS_NETMASK,
	MIB_DHCPS_GATEWAY,
	MIB_DHCPS_DNS_PRIMARY,
	MIB_DHCPS_DNS_SECONDARY,
	MIB_DHCPS_WINS_PRIMARY,
	MIB_DHCPS_WINS_SECONDARY,
	MIB_DHCPS_LEASE,			// in minutes
#endif//AG3120

	MIB_ETHERNET_STATS,			// read-only

	MIB_NETWORK_LAST
} MIBNetwork_t;

typedef enum MIBRemote_t
{
	MIB_REMOTE_FIRST		= MIB_WG302_BASE + 0x0200,

	MIB_RADIUS_IP			= MIB_REMOTE_FIRST,
	MIB_RADIUS_PORT,
	MIB_RADIUS_SECRET,

	MIB_SSH_DAEMON,

	MIB_SNMP_DAEMON,
	MIB_SNMPD_TRAP_SERVER,
	MIB_SNMPD_READ_COMMUNITY,
	MIB_SNMPD_WRITE_COMMUNITY,
	MIB_SNMPD_SYS_DESCRIPTION,
	MIB_SNMPD_SYS_CONTACT,
	MIB_SNMPD_SYS_LOCATION,
	
	MIB_SYSLOG_DAEMON,
	MIB_SYSLOG_SERVER_IP,
	MIB_SYSLOG_SERVER_PORT,

	MIB_HTTP_REDIRECT,			// (v2.1.1)
	MIB_HTTP_REDIRECT_URL,		// (v2.1.1)

	MIB_REMOTE_LAST
} MIBRemote;

typedef enum MIBWireless_t
{
	MIB_WLAN_FIRST			= MIB_WG302_BASE + 0x0300,

	MIB_WLAN_VERSION		= MIB_WLAN_FIRST,
	MIB_WLAN_SUPPORTED_XPD_GAIN,// read-only

	MIB_WLAN_LOCAL_MAC,
	MIB_WLAN_RADIO_ENABLE,
	MIB_WLAN_OPERATION_MODE,
	MIB_WLAN_WIRELESS_MODE,
	MIB_WLAN_SSID,
	MIB_WLAN_SSID_SUPPRESS,
	MIB_WLAN_SSID_BROADCAST,	// Forrest: reverse of MIB_WLAN_SSID_SUPPRESS
	MIB_WLAN_CHANNEL,
	MIB_WLAN_CHANNEL_ALL,
	MIB_WLAN_TRANSMIT_RATE,
	MIB_WLAN_TRANSMIT_POWER,

#if	defined(WG302) ||	defined(WAG302)
	MIB_WLAN_WMM,
	MIB_WLAN_WMM_NOACK,
#endif
	MIB_WLAN_RTS_THRESHOLD,
	MIB_WLAN_FRAGMENT_THRESHOLD,
	MIB_WLAN_BEACON_INTERVAL,
	MIB_WLAN_DTIM_INTERVAL,
#if	defined(ZAG5000) || defined(AG3120)
	MIB_WLAN_SPACE_IN_METER,
#endif	
	MIB_WLAN_ANTENNA,
	MIB_WLAN_PREAMBLE,
	MIB_WLAN_SUPER_AG_ENABLE,
	MIB_WLAN_WIRELESS_ISOLATION,
#if	defined(AG3120)
	MIB_WLAN_NETWORK_STATUS,		// read-only
	MIB_WLAN_AP_SCAN,
	MIB_WLAN_AP_SCANLIST,			// read-only
	MIB_WLAN_REMOTE_APINFO,			// read-only
	MIB_WLAN_REMOTE_BSSID,
	MIB_WLAN_REMOTE_SSID,
	MIB_WLAN_REMOTE_RSSI,			// read-only
#endif//AG3120
#if	defined(ZAG5000)
	MIB_WLAN_MAX_RSSI,
	MIB_WLAN_RF_LINE_WASTE,
	MIB_WLAN_LOCAL_PLUS,
	MIB_WLAN_REMOTE_PLUS,
	MIB_WLAN_REMOTE_MAC,
	MIB_WLAN_LINK_ACTION,
	MIB_WLAN_LINK_RX,
	MIB_WLAN_LINK_TX,
	MIB_WLAN_LINK_TIME,
	MIB_WLAN_LINK_PKT_SIZE,			// LinkTest Pkt's size
	MIB_WLAN_LINK_TEST_INTERVAL,	// LinkTest Send Pkt's interval
	MIB_WLAN_LINK_LOCAL_RSSI,
	MIB_WLAN_LINK_REMOTE_RSSI,
	MIB_WLAN_DOWN_FLOW_WIDTH,
#endif//ZAG5000
	MIB_WLAN_P2P_REMOTE_AP,
	MIB_WLAN_PXP_REMOTE_AP1,
	MIB_WLAN_PXP_REMOTE_AP2,
	MIB_WLAN_PXP_REMOTE_AP3,
	MIB_WLAN_PXP_REMOTE_AP4,
#if	defined(ZAG5000)
	MIB_WLAN_PXP_REMOTE_AP5,
	MIB_WLAN_PXP_REMOTE_AP6,
	MIB_WLAN_PXP_REMOTE_AP7,
	MIB_WLAN_PXP_REMOTE_AP8,
	MIB_WLAN_P2P_REMOTE_FLOW,
	MIB_WLAN_PXP_REMOTE_FLOW1,
	MIB_WLAN_PXP_REMOTE_FLOW2,
	MIB_WLAN_PXP_REMOTE_FLOW3,
	MIB_WLAN_PXP_REMOTE_FLOW4,
	MIB_WLAN_PXP_REMOTE_FLOW5,
	MIB_WLAN_PXP_REMOTE_FLOW6,
	MIB_WLAN_PXP_REMOTE_FLOW7,
	MIB_WLAN_PXP_REMOTE_FLOW8,
	MIB_WLAN_ISOLATION_WDS,
#endif//ZAG5000
	MIB_WLAN_REPEATER_REMOTE_AP1,
	MIB_WLAN_REPEATER_REMOTE_AP2,
	MIB_WLAN_REPEATER_REMOTE_AP3,
	MIB_WLAN_REPEATER_REMOTE_AP4,
#if	defined(AG3120) || defined(ZAG5000)
	MIB_WLAN_AUTOWDS_ID,
	MIB_WLAN_AUTOWDS_KEY,
	MIB_WLAN_AUTOWDS_REMOTE_LIST,
	MIB_WLAN_AUTOWDS_STATUS,
#endif//AG3120
	MIB_WLAN_ACL_MODE,
	MIB_WLAN_ACL_ALLOW_LIST,	// Read=Get, Write=Append, Remove=delete

#if	defined(AG3120) || defined(ZAG5000)
#else// NETGEAR
	MIB_WLAN_ROGUE_AP_DETECT,	// (v2.1.1), see MIB_PROBE_MODE
	MIB_WLAN_IDENTIFIED_AP_LIST,// (v2.1.1)
#endif//NETGEAR

	MIB_WLAN_ASSOCIATION_LIST,	// read-only
	MIB_WLAN_STATS,				// read-only

	MIB_WLAN_RESET_TIME,

	MIB_WLAN_LAST
} MIBWireless_t;

typedef enum MIBSecurity_t
{
	MIB_SECURITY_FIRST		= MIB_WG302_BASE + 0x0400,

	MIB_WLAN_AUTHENTICATION	= MIB_SECURITY_FIRST,
	MIB_WLAN_ENCRYPTION,

	MIB_WEP_KEY_TYPE,
	MIB_WEP_KEY_DEFAULT,
	MIB_WEP_KEY_PASS_PHRASE,
	MIB_WEP_KEY1,
	MIB_WEP_KEY2,
	MIB_WEP_KEY3,
	MIB_WEP_KEY4,

	MIB_WPA_PSK,
	MIB_WPA_RE_AUTH_SECONDS,
	MIB_WPA_GKEY_UPDATE_CONDITION,
	MIB_WPA_GKEY_UPDATE_SECONDS,
	MIB_WPA_GKEY_UPDATE_PACKETS,

	MIB_SECURITY_LAST
} MIBSecurity_t;

typedef enum MIBAutoCell_t
{
	MIB_AUTOCELL_FIRST		= MIB_WG302_BASE + 0x0500,

	MIB_AUTO_CELL			= MIB_AUTOCELL_FIRST,	
							// AutoCell (autocellEnable)
	MIB_SUPER_PRIVACY,		// Same as MIB_RF_COVERAGE
	MIB_AVOID_OTHER_WLAN,	// Automatically Avoid Other WLANS (autoAvoidWlanmode)

	MIB_RF_COVERAGE,		// Power Control Mode (autoCellPwrMode)
	MIB_PWR_LIMIT_MIN,		// Power Limit Min (tpBackoffCfgMin)
	MIB_PWR_LIMIT_RANGE,	// Power Limit Range (tpBackoffCfgRange)

	MIB_HOT_STANDBY,		// Hot Standby (standModeEnabled) (v2.1.0, default false)

	MIB_PROBE_MODE,			// Probe Mode* (apProbeModeEnabled) (v2.1.0)
	MIB_PROBE_SEQUENCE,		// increased when writing MIB_PROBE_MODE, Read-only (v2.1.0)
	MIB_RF_DOMAIN,			// Rf domain (v2.1.0)

	MIB_AUTOCELL_LAST
} MIBAutoCell_t;

#endif//!__WAG302MIB_H__
