#!/bin/bash
#

OEM_DIR='oem'
OEMS=`ls $OEM_DIR`
OEM=''

if [ _$1_ != __ ]; then
	for dir in $OEMS ; do
		if [ $dir == $1 ]; then
			OEM=$dir
		fi
	done
fi

# double check the oem directory
if [ ! -f $OEM_DIR\/$OEM\/makefile ]; then
	if [ _$OEM != _ ]; then 
		echo \'$OEM\' not a valid oem directory!
		echo ls -l $OEM_DIR/$OEM
		ls -l $OEM_DIR/$OEM
		echo
		OEM=''
	fi
fi 

export -n OEM_DIR

if [ _$OEM == _ ]; then
	echo Usage: . setenv.sh oem
	echo   valid oems are \'$OEMS\'
	export -n OEM
	export -n OEMS
	return
fi	

export -n OEMS

# default setting uses MVL3.0

# Set the Richfield directory
export RICHFIELD_DIR=`pwd`

# Change the following line to point to your linux kernel source tree
export LINUX_SRC=$RICHFIELD_DIR/linux-2.4.18_mvl30

# Change the following line to point to the root of your HardHat installation
export HARDHAT_BASE=/opt/hardhat

# You may want to edit the following to point to your ixp425_xscale_sw
# directory. Otherwise you must source this file from that directory.
export IX_XSCALE_SW=$RICHFIELD_DIR/ixp425_xscale_sw

# decide the oem project use MVL2.1 or MVL3.0?
MVL21_OEMS='netgear no_brand'
for dir in $MVL21_OEMS ; do
	if [ $dir == $OEM ] ; then
		echo Phase-I project
		export LINUX_SRC=$RICHFIELD_DIR/linux-2.4.17_mvl21 
		export HARDHAT_BASE=/opt/hardhat2.1 
	fi
done
export -n MVL21_OEMS

export OEM
export TOPDIR=$LINUX_SRC
export TOOLENV=linux

export PATH=$HARDHAT_BASE/host/bin:$HARDHAT_BASE/devkit/arm/xscale_be/bin:$PATH

# verify the directories are exist
if [ ! -d $LINUX_SRC ] ; then
	echo warning \'$LINUX_SRC\' not exist!
fi

if [ ! -d $IX_XSCALE_SW ] ; then
	echo warning \'$IX_XSCALE_SW\' not exist!
fi

if [ ! -d $HARDHAT_BASE ] ; then
	echo warning \'$HARDHAT_BASE\' not exist!
elif [ ! -d $HARDHAT_BASE/host/bin ] ; then
	echo warning \'$HARDHAT_BASE/host/bin\' not exist!
elif [ ! -d $HARDHAT_BASE/devkit/arm/xscale_be/bin ] ; then
	echo warning \'$HARDHAT_BASE/devkit/arm/xscale_be/bin\' not exist!
fi

# export IGW paths
export IGW_DIR=$RICHFIELD_DIR/igateway
export PRJ_DIR=$IGW_DIR/system/zcomixp
export OEM_DIR=$RICHFIELD_DIR/oem/$OEM
export PUB_DIR=$RICHFIELD_DIR/oem/public
export PORT_DIR=$IGW_DIR/porting/linux

if [ `whoami` != root ] ; then
	export EXEC_AS_ROOT=exec_as_root
fi

cd $OEM_DIR
